@@ -6,9 +6,10 @@ from requests_oauthlib import OAuth1
 
 from . import __version__
 from .advisory import TwythonDeprecationWarning
-from .compat import json, urlencode, parse_qsl, quote_plus
+from .compat import json, urlencode, parse_qsl, quote_plus, str, is_py2
 from .endpoints import api_table
 from .exceptions import TwythonError, TwythonAuthError, TwythonRateLimitError
+from .helpers import _transparent_params
 
 warnings.simplefilter('always', TwythonDeprecationWarning)  # For Python 2.7 >
 
@@ -105,6 +106,9 @@ class Twython(object):
         # create stash for last call intel
         self._last_call = None
 
+    def __repr__(self):
+        return '<Twython: %s>' % (self.app_key)
+
     def _constructFunc(self, api_call, deprecated_key, **kwargs):
         # Go through and replace any mustaches that are in our API url.
         fn = api_table[api_call]
@@ -114,7 +118,7 @@ class Twython(object):
             self.api_url % self.api_version + fn['url']
         )
 
-        if deprecated_key:
+        if deprecated_key and (deprecated_key != api_call):
             # Until Twython 3.0.0 and the function is removed.. send deprecation warning
             warnings.warn(
                 '`%s` is deprecated, please use `%s` instead.' % (deprecated_key, api_call),
@@ -126,7 +130,7 @@ class Twython(object):
 
         return content
 
-    def _request(self, url, method='GET', params=None, files=None, api_call=None):
+    def _request(self, url, method='GET', params=None, api_call=None):
         '''Internal response generator, no sense in repeating the same
         code twice, right? ;)
         '''
@@ -134,6 +138,7 @@ class Twython(object):
         params = params or {}
 
         func = getattr(self.client, method)
+        params, files = _transparent_params(params)
         if method == 'get':
             response = func(url, params=params)
         else:
@@ -169,7 +174,10 @@ class Twython(object):
             # If there is no error message, use a default.
             errors = content.get('errors',
                                  [{'message': 'An error occurred processing your request.'}])
-            error_message = errors[0]['message']
+            if errors and isinstance(errors, list):
+                error_message = errors[0]['message']
+            else:
+                error_message = errors
             self._last_call['api_error'] = error_message
 
             ExceptionType = TwythonError
@@ -198,7 +206,7 @@ class Twython(object):
     we haven't gotten around to putting it in Twython yet. :)
     '''
 
-    def request(self, endpoint, method='GET', params=None, files=None, version='1.1'):
+    def request(self, endpoint, method='GET', params=None, version='1.1'):
         # In case they want to pass a full Twitter URL
         # i.e. https://search.twitter.com/
         if endpoint.startswith('http://') or endpoint.startswith('https://'):
@@ -206,15 +214,15 @@ class Twython(object):
         else:
             url = '%s/%s.json' % (self.api_url % version, endpoint)
 
-        content = self._request(url, method=method, params=params, files=files, api_call=url)
+        content = self._request(url, method=method, params=params, api_call=url)
 
         return content
 
     def get(self, endpoint, params=None, version='1.1'):
         return self.request(endpoint, params=params, version=version)
 
-    def post(self, endpoint, params=None, files=None, version='1.1'):
-        return self.request(endpoint, 'POST', params=params, files=files, version=version)
+    def post(self, endpoint, params=None, version='1.1'):
+        return self.request(endpoint, 'POST', params=params, version=version)
 
     # End Dynamic Request Methods
 
@@ -240,12 +248,14 @@ class Twython(object):
     def get_authentication_tokens(self, callback_url=None, force_login=False, screen_name=''):
         """Returns a dict including an authorization URL (auth_url) to direct a user to
 
-            :param callback_url: (optional.. for now) Url the user is returned to after they authorize your app
+            :param callback_url: (optional) Url the user is returned to after they authorize your app (web clients only)
             :param force_login: (optional) Forces the user to enter their credentials to ensure the correct users account is authorized.
             :param app_secret: (optional) If forced_login is set OR user is not currently logged in, Prefills the username input box of the OAuth login screen with the given value
         """
         callback_url = callback_url or self.callback_url
-        request_args = {'oauth_callback': callback_url}
+        request_args = {}
+        if callback_url:
+            request_args['oauth_callback'] = callback_url
         response = self.client.get(self.request_token_url, params=request_args)
 
         if response.status_code == 401:
@@ -280,7 +290,7 @@ class Twython(object):
     def get_authorized_tokens(self, oauth_verifier):
         """Returns authorized tokens after they go through the auth_url phase.
 
-        :param oauth_verifier: (required) The oauth_verifier retrieved from the callback url querystring
+        :param oauth_verifier: (required) The oauth_verifier (or a.k.a PIN for non web apps) retrieved from the callback url querystring
         """
         response = self.client.get(self.access_token_url, params={'oauth_verifier': oauth_verifier})
         authorized_tokens = dict(parse_qsl(response.content.decode('utf-8')))
@@ -338,8 +348,15 @@ class Twython(object):
         return Twython.construct_api_url(base_url, params)
 
     @staticmethod
-    def construct_api_url(base_url, params):
-        return base_url + '?' + '&'.join(['%s=%s' % (Twython.unicode2utf8(key), quote_plus(Twython.unicode2utf8(value))) for (key, value) in params.iteritems()])
+    def construct_api_url(base_url, params=None):
+        querystring = []
+        params, _ = _transparent_params(params or {})
+        params = requests.utils.to_key_val_list(params)
+        for (k, v) in params:
+            querystring.append(
+                '%s=%s' % (Twython.encode(k), quote_plus(Twython.encode(v)))
+            )
+        return '%s?%s' % (base_url, '&'.join(querystring))
 
     def searchGen(self, search_query, **kwargs):
         warnings.warn(
@@ -377,114 +394,10 @@ class Twython(object):
         for tweet in self.searchGen(search_query, **kwargs):
             yield tweet
 
-    # The following methods are apart from the other Account methods,
-    # because they rely on a whole multipart-data posting function set.
-
-    ## Media Uploading functions ##############################################
-
-    def updateProfileBackgroundImage(self, file_, version='1.1', **params):
-        warnings.warn(
-            'This method is deprecated, please use `update_profile_background_image` instead.',
-            TwythonDeprecationWarning,
-            stacklevel=2
-        )
-        return self.update_profile_background_image(file_, version, **params)
-
-    def update_profile_background_image(self, file_, version='1.1', **params):
-        """Updates the authenticating user's profile background image.
-
-            :param file_: (required) A string to the location of the file
-                          (less than 800KB in size, larger than 2048px width will scale down)
-            :param version: (optional) A number, default 1.1 because that's the
-                            current API version for Twitter (Legacy = 1)
-
-            **params - You may pass items that are stated in this doc
-                       (https://dev.twitter.com/docs/api/1.1/post/account/update_profile_background_image)
-        """
-
-        return self.post('account/update_profile_background_image',
-                         params=params,
-                         files={'image': (file_, open(file_, 'rb'))},
-                         version=version)
-
-    def updateProfileImage(self, file_, version='1.1', **params):
-        warnings.warn(
-            'This method is deprecated, please use `update_profile_image` instead.',
-            TwythonDeprecationWarning,
-            stacklevel=2
-        )
-        return self.update_profile_image(file_, version, **params)
-
-    def update_profile_image(self, file_, version='1.1', **params):
-        """Updates the authenticating user's profile image (avatar).
-
-            :param file_: (required) A string to the location of the file
-            :param version: (optional) A number, default 1.1 because that's the
-                            current API version for Twitter (Legacy = 1)
-
-            **params - You may pass items that are stated in this doc
-                       (https://dev.twitter.com/docs/api/1.1/post/account/update_profile_image)
-        """
-
-        return self.post('account/update_profile_image',
-                         params=params,
-                         files={'image': (file_, open(file_, 'rb'))},
-                         version=version)
-
-    def updateStatusWithMedia(self, file_, version='1.1', **params):
-        warnings.warn(
-            'This method is deprecated, please use `update_status_with_media` instead.',
-            TwythonDeprecationWarning,
-            stacklevel=2
-        )
-        return self.update_status_with_media(file_, version, **params)
-
-    def update_status_with_media(self, file_, version='1.1', **params):
-        """Updates the users status with media
-
-            :param file_: (required) A string to the location of the file
-            :param version: (optional) A number, default 1.1 because that's the
-                            current API version for Twitter (Legacy = 1)
-
-            **params - You may pass items that are taken in this doc
-                       (https://dev.twitter.com/docs/api/1.1/post/statuses/update_with_media)
-        """
-
-        return self.post('statuses/update_with_media',
-                         params=params,
-                         files={'media': (file_, open(file_, 'rb'))},
-                         version=version)
-
-    def updateProfileBannerImage(self, file_, version='1.1', **params):
-        warnings.warn(
-            'This method is deprecated, please use `update_profile_banner_image` instead.',
-            TwythonDeprecationWarning,
-            stacklevel=2
-        )
-        return self.update_profile_banner_image(file_, version, **params)
-
-    def update_profile_banner_image(self, file_, version='1.1', **params):
-        """Updates the users profile banner
-
-            :param file_: (required) A string to the location of the file
-            :param version: (optional) A number, default 1 because that's the
-                            only API version for Twitter that supports this call
-
-            **params - You may pass items that are taken in this doc
-                       (https://dev.twitter.com/docs/api/1.1/post/account/update_profile_banner)
-        """
-
-        return self.post('account/update_profile_banner',
-                         params=params,
-                         files={'banner': (file_, open(file_, 'rb'))},
-                         version=version)
-
-    ###########################################################################
-
     @staticmethod
     def unicode2utf8(text):
         try:
-            if isinstance(text, unicode):
+            if is_py2 and isinstance(text, str):
                 text = text.encode('utf-8')
         except:
             pass
@@ -492,6 +405,6 @@ class Twython(object):
 
     @staticmethod
     def encode(text):
-        if isinstance(text, (str, unicode)):
+        if is_py2 and isinstance(text, (str)):
             return Twython.unicode2utf8(text)
         return str(text)
